==> scala-k8s-objects_sjs1_3-0.5.1-sources.jar: io/k8s/api/networking/v1/IngressClassParametersReference.scala <==
package io.k8s.api.networking.v1

import dev.hnaderi.k8s.utils._

/** IngressClassParametersReference identifies an API object. This can be used to specify a cluster or namespace-scoped resource. */
final case class IngressClassParametersReference(
  name : String,
  scope : Option[String] = None,
  apiGroup : Option[String] = None,
  namespace : Option[String] = None
) {

  /** Returns a new data with name set to new value */
  def withName(value: String) : IngressClassParametersReference = copy(name = value)
  /** transforms name to result of function */
  def mapName(f: String => String) : IngressClassParametersReference = copy(name = f(name))

  /** Returns a new data with scope set to new value */
  def withScope(value: String) : IngressClassParametersReference = copy(scope = Some(value))
  /** if scope has a value, transforms to the result of function*/
  def mapScope(f: String => String) : IngressClassParametersReference = copy(scope = scope.map(f))

  /** Returns a new data with apiGroup set to new value */
  def withApiGroup(value: String) : IngressClassParametersReference = copy(apiGroup = Some(value))
  /** if apiGroup has a value, transforms to the result of function*/
  def mapApiGroup(f: String => String) : IngressClassParametersReference = copy(apiGroup = apiGroup.map(f))

  /** Returns a new data with namespace set to new value */
  def withNamespace(value: String) : IngressClassParametersReference = copy(namespace = Some(value))
  /** if namespace has a value, transforms to the result of function*/
  def mapNamespace(f: String => String) : IngressClassParametersReference = copy(namespace = namespace.map(f))
}

object IngressClassParametersReference {

    implicit val encoder : Encoder[io.k8s.api.networking.v1.IngressClassParametersReference] = new Encoder[io.k8s.api.networking.v1.IngressClassParametersReference] {
        def apply[T : Builder](o: io.k8s.api.networking.v1.IngressClassParametersReference) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("name", o.name)
            .write("scope", o.scope)
            .write("apiGroup", o.apiGroup)
            .write("namespace", o.namespace)
            .build
        }
    }

    implicit val decoder: Decoder[IngressClassParametersReference] = new Decoder[IngressClassParametersReference] {
      def apply[T : Reader](t: T): Either[String, IngressClassParametersReference] = for {
          obj <- ObjectReader(t)
          name <- obj.read[String]("name")
          scope <- obj.readOpt[String]("scope")
          apiGroup <- obj.readOpt[String]("apiGroup")
          namespace <- obj.readOpt[String]("namespace")
      } yield IngressClassParametersReference (
          name = name,
          scope = scope,
          apiGroup = apiGroup,
          namespace = namespace
        )
    }
}

==> scala-k8s-objects_sjs1_3-0.11.1-sources.jar: io/k8s/api/networking/v1/IngressClassParametersReference.scala <==
package io.k8s.api.networking.v1

import dev.hnaderi.k8s.utils._

/** IngressClassParametersReference identifies an API object. This can be used to specify a cluster or namespace-scoped resource. */
final case class IngressClassParametersReference(
  name : String,
  kind : String,
  scope : Option[String] = None,
  apiGroup : Option[String] = None,
  namespace : Option[String] = None
) {

  /** Returns a new data with name set to new value */
  def withName(value: String) : IngressClassParametersReference = copy(name = value)
  /** transforms name to result of function */
  def mapName(f: String => String) : IngressClassParametersReference = copy(name = f(name))

  /** Returns a new data with kind set to new value */
  def withKind(value: String) : IngressClassParametersReference = copy(kind = value)
  /** transforms kind to result of function */
  def mapKind(f: String => String) : IngressClassParametersReference = copy(kind = f(kind))

  /** Returns a new data with scope set to new value */
  def withScope(value: String) : IngressClassParametersReference = copy(scope = Some(value))
  /** if scope has a value, transforms to the result of function*/
  def mapScope(f: String => String) : IngressClassParametersReference = copy(scope = scope.map(f))

  /** Returns a new data with apiGroup set to new value */
  def withApiGroup(value: String) : IngressClassParametersReference = copy(apiGroup = Some(value))
  /** if apiGroup has a value, transforms to the result of function*/
  def mapApiGroup(f: String => String) : IngressClassParametersReference = copy(apiGroup = apiGroup.map(f))

  /** Returns a new data with namespace set to new value */
  def withNamespace(value: String) : IngressClassParametersReference = copy(namespace = Some(value))
  /** if namespace has a value, transforms to the result of function*/
  def mapNamespace(f: String => String) : IngressClassParametersReference = copy(namespace = namespace.map(f))
}

object IngressClassParametersReference {

    implicit val encoder : Encoder[io.k8s.api.networking.v1.IngressClassParametersReference] = new Encoder[io.k8s.api.networking.v1.IngressClassParametersReference] {
        def apply[T : Builder](o: io.k8s.api.networking.v1.IngressClassParametersReference) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("name", o.name)
            .write("kind", o.kind)
            .write("scope", o.scope)
            .write("apiGroup", o.apiGroup)
            .write("namespace", o.namespace)
            .build
        }
    }

    implicit val decoder: Decoder[IngressClassParametersReference] = new Decoder[IngressClassParametersReference] {
      def apply[T : Reader](t: T): Either[String, IngressClassParametersReference] = for {
          obj <- ObjectReader(t)
          name <- obj.read[String]("name")
          kind <- obj.read[String]("kind")
          scope <- obj.readOpt[String]("scope")
          apiGroup <- obj.readOpt[String]("apiGroup")
          namespace <- obj.readOpt[String]("namespace")
      } yield IngressClassParametersReference (
          name = name,
          kind = kind,
          scope = scope,
          apiGroup = apiGroup,
          namespace = namespace
        )
    }
}
